@@ -51,9 +51,9 @@ class MqttConnector(Connector, Thread):
         self.__disconnect_requests = []
         self.__attribute_requests = []
         self.__attribute_updates = []
-        # self.lastDataDict = {}
-        # self.lastDataDict[clientID] = {}
-        #self.initLastDataDict(clientID)
+        self.lastDataDict = {}
+        self.lastDataDict[clientID] = {}
+        self.initLastDataDict(clientID)
         mandatory_keys = {
             "mapping": ['topicFilter', 'converter'],
             # "serverSideRpc": ['deviceNameFilter', 'methodFilter', 'requestTopicExpression', 'valueExpression'],
@@ -409,15 +409,15 @@ class MqttConnector(Connector, Thread):
         self.statistics['MessagesReceived'] += 1
         topic = message.topic
         node_id = message.topic.split("/")[1]
-        if node_id != self.__client_ID.split('-')[1]:
-            return
-        else:
-            topic = topic.replace('/' + node_id, '')
+        # if node_id != self.__client_ID.split('-')[1]:
+        #     return
+        # else:
+        topic = topic.replace('/' + node_id, '')
         valid_topic = self.check_topic(topic)
         content = TBUtility.decode(message)
-        # if self.is_connected():
-            # if self.checkTelemetryUpdate(self.__client_ID, valid_topic, content) is True:
-            #     return
+        if self.is_connected():
+            if self.checkTelemetryUpdate(self.__client_ID, valid_topic, content) is True:
+                return
         # Check if message topic exists in mappings "i.e., I'm posting telemetry/attributes" ---------------------------
         topic_handlers = [
             regex for regex in self.__mapping_sub_topics if fullmatch(regex, valid_topic)]
@@ -567,7 +567,7 @@ class MqttConnector(Connector, Thread):
                     handler = self.__attribute_requests_sub_topics[topic]
 
                     found_device_name = None
-                    found_attribute_name = None
+                    found_attribute_names = None
 
                     # Get device name, either from topic or from content
                     if handler.get("deviceNameTopicExpression"):
@@ -584,30 +584,28 @@ class MqttConnector(Connector, Thread):
                         attribute_name_match = search(
                             handler["attributeNameTopicExpression"], message.topic)
                         if attribute_name_match is not None:
-                            found_attribute_name = attribute_name_match.group(
-                                0)
+                            found_attribute_names = attribute_name_match.group(0)
                     elif handler.get("attributeNameJsonExpression"):
-                        found_attribute_name = TBUtility.get_value(
-                            handler["attributeNameJsonExpression"], content)
+                        found_attribute_names = list(filter(lambda x: x is not None,
+                                                            TBUtility.get_values(handler["attributeNameJsonExpression"],
+                                                                                 content)))
 
                     if found_device_name is None:
                         self.__log.error(
                             "Device name missing from attribute request")
                         continue
 
-                    if found_attribute_name is None:
-                        self.__log.error(
-                            "Attribute name missing from attribute request")
+                    if found_attribute_names is None:
+                        self.__log.error("Attribute name missing from attribute request")
                         continue
 
-                    self.__log.info("Will retrieve attribute %s of %s",
-                                    found_attribute_name, found_device_name)
+                    self.__log.info("Will retrieve attribute %s of %s", found_attribute_names, found_device_name)
                     self.__gateway.tb_client.client.gw_request_shared_attributes(
                         found_device_name,
-                        [found_attribute_name],
+                        found_attribute_names,
                         lambda data, *args: self.notify_attribute(
                             data,
-                            found_attribute_name,
+                            found_attribute_names,
                             handler.get("topicExpression"),
                             handler.get("valueExpression"),
                             handler.get('retain', False)))
@@ -634,18 +632,21 @@ class MqttConnector(Connector, Thread):
                          content)
 
     def notify_attribute(self, incoming_data, attribute_name, topic_expression, value_expression, retain):
-        if incoming_data.get("device") is None or incoming_data.get("value") is None:
+        if incoming_data.get("device") is None or incoming_data.get("value", incoming_data.get('values')) is None:
             return
 
         device_name = incoming_data.get("device")
-        attribute_value = incoming_data.get("value")
+        attribute_values = incoming_data.get('value') or incoming_data.get('values')
 
         topic = topic_expression \
             .replace("${deviceName}", str(device_name)) \
             .replace("${attributeKey}", str(attribute_name))
 
-        data = value_expression.replace("${attributeKey}", str(attribute_name)) \
-            .replace("${attributeValue}", str(attribute_value))
+        if len(attribute_name) <= 1:
+            data = value_expression.replace("${attributeKey}", str(attribute_name[0])) \
+                .replace("${attributeValue}", str(attribute_values))
+        else:
+            data = simplejson.dumps(attribute_values)
 
         self._client.publish(topic, data, retain=retain).wait_for_publish()
 
@@ -758,8 +759,7 @@ class MqttConnector(Connector, Thread):
 
                 data_to_send = rpc_config.get('valueExpression')
                 for (tag, value) in zip(data_to_send_tags, data_to_send_values):
-                    data_to_send = data_to_send.replace(
-                        '${' + tag + '}', str(value))
+                    data_to_send = data_to_send.replace('${' + tag + '}', simplejson.dumps(value))
 
                 try:
                     self.__log.info("Publishing to: %s with data %s",
