@@ -331,7 +331,7 @@ class TBDeviceMqttClient:
         return info
 
     def _add_timeout(self, attr_request_number, timestamp):
-        log.info("Attr. req. num", attr_request_number)
+        log.info("Attr. req. num" + str(attr_request_number))
         self.__timeout_queue.put({"ts": timestamp, "attribute_request_id": attr_request_number})
 
     def _add_attr_request_callback(self, callback):
